/*****************************************************************************************
 Copyright (c) 2002-2004 The UbixOS Project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without modification, are
 permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice, this list of
 conditions, the following disclaimer and the list of authors.  Redistributions in binary
 form must reproduce the above copyright notice, this list of conditions, the following
 disclaimer and the list of authors in the documentation and/or other materials provided
 with the distribution. Neither the name of the UbixOS Project nor the names of its
 contributors may be used to endorse or promote products derived from this software
 without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 $Id$

*****************************************************************************************/

#include <sys/types.h>
#include <sys/mpi.h>

int mpiCreateMbox(char *name) { 
  int status = 0x0;
  asm(
    "int %0\n"
    : : "i" (0x80),"a" (50),"b" (&status),"c" (name)
    );

  return(status);
  }

int mpiDestroyMbox(char *name) {
  int status = 0x0;
  asm(
    "int %0\n"
    : : "i" (0x80),"a" (51),"b" (&status),"c" (name)
    );

  return(status);
  }

int mpiPostMessage(char *name,uInt32 type,void *data) {
  asm(
    "int %0\n"
    : : "i" (0x80),"a" (52),"b" (name),"c" (&type),"d" (data)
    );
  return(type);
  }

int mpiFetchMessage(char *name,mpiMessage_t *msg) {
  int status = 0x0;
  asm(
    "int %0\n"
    : : "i" (0x80),"a" (53),"b" (name),"c" (msg),"d" (&status)
    );
  return(status);
  }

int mpiSpam(uInt32 type,void *data) {
  int status = 0x0;
  asm(
    "int %0\n"
    : : "i" (0x80),"a" (54),"b" (type),"c" (data),"d" (&status)
    );
  return(status);
  }

/***
 $Log$
 Revision 1.2  2004/05/26 15:39:22  reddawg
 mpi: brought mpiDestroyMbox(char *name) in to the userland

 Revision 1.1  2004/05/25 15:43:27  reddawg
 Added Userland MPI access

 END
 ***/

