/*****************************************************************************************
 Copyright (c) 2002-2004 The UbixOS Project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without modification, are
 permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice, this list of
 conditions, the following disclaimer and the list of authors.  Redistributions in binary
 form must reproduce the above copyright notice, this list of conditions, the following
 disclaimer and the list of authors in the documentation and/or other materials provided
 with the distribution. Neither the name of the UbixOS Project nor the names of its
 contributors may be used to endorse or promote products derived from this software
 without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 $Id$

*****************************************************************************************/

#include <ubixos/syscall.h>
#include <ubixos/syscalls.h>
#include <ubixos/sched.h>
#include <ubixos/types.h>
#include <ubixos/exec.h>
#include <ubixos/elf.h>
#include <ubixos/vitals.h>
#include <ubixos/endtask.h>
#include <sys/video.h>
#include <vmm/vmm.h>
#include <vfs/file.h>
#include <ubixfs/ubixfs.h>
#include <lib/string.h>
#include <lib/kprintf.h>
#include <lib/kmalloc.h>
#include <sde/sde.h>
#include <mpi/mpi.h>

void sdeTestThread();

asm(
  ".globl _sysCall              \n"
  "_sysCall:                    \n"
  "  cmpl totalCalls,%eax       \n"
  "  jae invalidSysCall         \n"  
  "  pushl %edx                 \n"
  "  pushl %ecx                 \n"
  "  pushl %ebx                 \n"
  "  call *systemCalls(,%eax,4) \n"
  "  jmp done                   \n"
  "invalidSysCall:              \n"
  "  call invalidCall           \n"
  "done:                        \n"
  "  popl %ebx                  \n"
  "  popl %ecx                  \n"
  "  popl %edx                  \n"
  "  iret                       \n" /* Exit interrupt               */
  );

void invalidCall() {
  kprintf("Invalid Sys Call!\n");
  }

void sysGetpid(int *pid) {
  *pid = _current->id;
  return;
  }

void sysGetUid(int *uid) {
  *uid = _current->uid;
  return;
  }

void sysGetGid(int *gid) {
  *gid = _current->gid;
  return;
  }

void sysSetUid(int uid,int *status) {
  if (_current->uid == 0x0) {
    _current->uid = uid;
    *status = 0x0;
    }
  else {
    *status = 1;
    }
  return;
  }

void sysSetGid(int gid,int *status) {
  if (_current->gid == 0x0) {
    _current->gid = gid;
    *status = 0x0;
    }
  else {
    *status = 1;
    }
  return;
  }  

void sysExit(int status) {
  endTask(_current->id);
  sched();
  }

void sysCheckPid(int pid,int *ptr) {
  *ptr = schedFindTask(pid)->state;
  return;
  }

/************************************************************************

Function: void sysGetFreePage();
Description: Allocs A Page To The Users VM Space
Notes:

************************************************************************/  
void sysGetFreePage(long *ptr,int count) {
  *ptr = (long) vmmGetFreeVirtualPage(_current->id,count);
  return;
  }

void sysGetDrives(uInt32 *ptr) {
  *ptr = 0x0;//(uInt32)devices;
  return;
  }

void sysGetUptime(uInt32 *ptr) {
  *ptr = systemVitals->sysTicks;
  return;
  }

void sysGetTime(uInt32 *ptr) {
  *ptr = systemVitals->sysUptime + systemVitals->timeStart;
  return;
  }


void sysGetCwd(char *data) {
  sprintf(data,_current->oInfo.cwd);
  return;
  }

void sysSchedYield() {
  schedYield();
  }

void sysStartSDE() {
  int i = 0x0;
  for (i=0;i<1400;i++) {
    asm("hlt");
    }
  execThread(sdeThread,(uInt32)(kmalloc(0x2000)+0x2000),0x0);
  for (i=0;i<1400;i++) {
    asm("hlt");
    }
  return;
  }

void sysMpiCreateMbox(uInt32 *status,char *name) {
  *status = mpiCreateMbox(name); 
  return;
  }

void sysMpiDestroyMbox(uInt32 *status,char *name) {
  *status = mpiDestroyMbox(name);
  return;
  }

void sysMpiPostMessage(char *name,uInt32 *type,void *data) {
  *type = mpiPostMessage(name,*type,data);
  return;
  }

void sysMpiFetchMessage(char *name,mpiMessage_t *msg,uInt32 *status) {
  *status = mpiFetchMessage(name,msg);
  return;
  }

void sysMpiSpam(uInt32 type,void *data,uInt32 *status) {
  *status = mpiSpam(type,data);
  return;
  }

/***
 $Log$
 Revision 1.14  2004/06/17 03:20:47  reddawg
 Cleaned Up

 Revision 1.13  2004/05/26 15:39:22  reddawg
 mpi: brought mpiDestroyMbox(char *name) in to the userland

 Revision 1.12  2004/05/26 13:07:54  reddawg
 mpi: had problem with mpiCreateMbox interface was putting garbage on end

 Revision 1.11  2004/05/25 15:49:03  reddawg
 Added Syscall Interface For MPI

 Revision 1.10  2004/05/23 01:10:35  reddawg
 Fixes: Started to fix re-entrancy issues many more to look into

 Revision 1.9  2004/05/21 21:15:04  reddawg
 Fixed a few bugs which prevented the system from loadin

 Revision 1.8  2004/05/21 12:46:02  reddawg
 Cleaned up

 Revision 1.7  2004/05/19 17:28:28  reddawg
 Added the correct endTask Procedure

 Revision 1.6  2004/05/19 04:07:43  reddawg
 kmalloc(size,pid) no more it is no kmalloc(size); the way it should of been

 Revision 1.5  2004/05/19 01:21:29  reddawg
 Tweaked

 Revision 1.4  2004/05/15 02:30:28  reddawg
 Lots of changes


 END
 ***/

